@@ -21,8 +21,8 @@ fi
 
 VIZDOOM_PK3_PATH="${BIN_PATH}/vizdoom.pk3"
 PYTHON_BIN_PATH="$(ls ${PACKAGE_DEST_DIRECTORY}/vizdoom*)"
-
 FREEDOOM_PATH="${SRC_PATH}/src/freedoom2.wad"
+BOTS_PATH="${SRC_PATH}/src/bots.cfg"
 SCENARIOS_DEST_DIR="${PACKAGE_DEST_PATH}/scenarios"
 SCENARIOS_PATH="${SRC_PATH}/scenarios"
 GYM_WRAPPER_DEST_DIR="${PACKAGE_DEST_PATH}/gym_wrapper"
@@ -46,6 +46,8 @@ cp ${PYTHON_BIN_PATH} ${PACKAGE_DEST_PATH}
 cp ${VIZDOOM_EXEC_PATH} ${PACKAGE_DEST_PATH}
 cp ${VIZDOOM_PK3_PATH} ${PACKAGE_DEST_PATH}
 cp ${FREEDOOM_PATH} ${PACKAGE_DEST_PATH}
+cp ${BOTS_PATH} ${PACKAGE_DEST_PATH}
+
 mkdir -p ${SCENARIOS_DEST_DIR}
 cp ${SCENARIOS_PATH}/*.wad ${SCENARIOS_DEST_DIR}
 cp ${SCENARIOS_PATH}/*.cfg ${SCENARIOS_DEST_DIR}
