@@ -92,6 +92,9 @@ PYBIND11_MODULE(vizdoom, vz){
     CONST_2_PYT(MAX_PLAYER_NAME_LENGTH);
     CONST_2_PYT(USER_VARIABLE_COUNT);
     CONST_2_PYT(DEFAULT_TICRATE);
+    CONST_2_PYT(DEFAULT_FPS);
+    CONST_2_PYT(DEFAULT_FRAMETIME_MS);
+    CONST_2_PYT(DEFAULT_FRAMETIME_S);
 
     CONST_2_PYT(BINARY_BUTTON_COUNT);
     CONST_2_PYT(DELTA_BUTTON_COUNT);
